Index: include/core/SkRefCnt.h |
=================================================================== |
--- include/core/SkRefCnt.h (revision 12696) |
+++ include/core/SkRefCnt.h (working copy) |
@@ -50,7 +50,7 @@ |
bool unique() const { |
bool const unique = (1 == fRefCnt); |
if (unique) { |
// Aquire barrier (L/SL), if not provided by load of fRefCnt. |
// Prevents user's 'unique' code from happening before decrements. |
//TODO: issue the barrier. |
} |
@@ -72,9 +72,9 @@ |
SkASSERT(fRefCnt > 0); |
// Release barrier (SL/S), if not provided below. |
if (sk_atomic_dec(&fRefCnt) == 1) { |
// Aquire barrier (L/SL), if not provided above. |
// Prevents code in dispose from happening before the decrement. |
- sk_membar_aquire__after_atomic_dec(); |
+ sk_membar_acquire__after_atomic_dec(); |
internal_dispose(); |
} |
} |
@@ -50,7 +50,7 @@ |
bool const unique = (1 == fRefCnt); |
if (unique) { |
- // Aquire barrier (L/SL), if not provided by load of fRefCnt. |
+ // Acquire barrier (L/SL), if not provided by load of fRefCnt. |
// Prevents user's 'unique' code from happening before decrements. |
//TODO: issue the barrier. |
@@ -72,9 +72,9 @@ |
// Release barrier (SL/S), if not provided below. |
if (sk_atomic_dec(&fRefCnt) == 1) { |
- // Aquire barrier (L/SL), if not provided above. |
+ // Acquire barrier (L/SL), if not provided above. |
// Prevents code in dispose from happening before the decrement. |